# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dentmeter.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dentmeter.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0f\x64\x65ntmeter.proto\x12\x06xbospb\"B\n\x0e\x44\x65ntMeterState\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\"\n\x06phases\x18\x02 \x03(\x0b\x32\x12.xbospb.PhaseState\"\xbf\x02\n\nPhaseState\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x12\n\nannotation\x18\x0e \x01(\t\x12\x13\n\x0btrue_energy\x18\x02 \x01(\x01\x12\x17\n\x0freactive_energy\x18\x03 \x01(\x01\x12\x17\n\x0f\x61pparent_energy\x18\x04 \x01(\x01\x12\x12\n\ntrue_power\x18\x05 \x01(\x01\x12\x16\n\x0ereactive_power\x18\x06 \x01(\x01\x12\x16\n\x0e\x61pparent_power\x18\x07 \x01(\x01\x12\x17\n\x0f\x64isplacement_pf\x18\x08 \x01(\x01\x12\x13\n\x0b\x61pparent_pf\x18\t \x01(\x01\x12\x0f\n\x07\x63urrent\x18\n \x01(\x01\x12\x16\n\x0eline_frequency\x18\x0b \x01(\x01\x12\r\n\x05volts\x18\x0c \x01(\x01\x12\x1d\n\x15phase_neutral_voltage\x18\r \x01(\x01\x62\x06proto3')
)




_DENTMETERSTATE = _descriptor.Descriptor(
  name='DentMeterState',
  full_name='xbospb.DentMeterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.DentMeterState.time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phases', full_name='xbospb.DentMeterState.phases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=93,
)


_PHASESTATE = _descriptor.Descriptor(
  name='PhaseState',
  full_name='xbospb.PhaseState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='xbospb.PhaseState.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='xbospb.PhaseState.annotation', index=1,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='true_energy', full_name='xbospb.PhaseState.true_energy', index=2,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactive_energy', full_name='xbospb.PhaseState.reactive_energy', index=3,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_energy', full_name='xbospb.PhaseState.apparent_energy', index=4,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='true_power', full_name='xbospb.PhaseState.true_power', index=5,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactive_power', full_name='xbospb.PhaseState.reactive_power', index=6,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_power', full_name='xbospb.PhaseState.apparent_power', index=7,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displacement_pf', full_name='xbospb.PhaseState.displacement_pf', index=8,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_pf', full_name='xbospb.PhaseState.apparent_pf', index=9,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current', full_name='xbospb.PhaseState.current', index=10,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_frequency', full_name='xbospb.PhaseState.line_frequency', index=11,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volts', full_name='xbospb.PhaseState.volts', index=12,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase_neutral_voltage', full_name='xbospb.PhaseState.phase_neutral_voltage', index=13,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=415,
)

_DENTMETERSTATE.fields_by_name['phases'].message_type = _PHASESTATE
DESCRIPTOR.message_types_by_name['DentMeterState'] = _DENTMETERSTATE
DESCRIPTOR.message_types_by_name['PhaseState'] = _PHASESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DentMeterState = _reflection.GeneratedProtocolMessageType('DentMeterState', (_message.Message,), dict(
  DESCRIPTOR = _DENTMETERSTATE,
  __module__ = 'dentmeter_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.DentMeterState)
  ))
_sym_db.RegisterMessage(DentMeterState)

PhaseState = _reflection.GeneratedProtocolMessageType('PhaseState', (_message.Message,), dict(
  DESCRIPTOR = _PHASESTATE,
  __module__ = 'dentmeter_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.PhaseState)
  ))
_sym_db.RegisterMessage(PhaseState)


# @@protoc_insertion_point(module_scope)
