# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brick.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='brick.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0b\x62rick.proto\x12\x06xbospb\x1a google/protobuf/descriptor.proto\"\'\n\x03URI\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"c\n\x06Triple\x12\x1c\n\x07subject\x18\x01 \x01(\x0b\x32\x0b.xbospb.URI\x12\x1e\n\tpredicate\x18\x02 \x01(\x0b\x32\x0b.xbospb.URI\x12\x1b\n\x06object\x18\x03 \x01(\x0b\x32\x0b.xbospb.URI:H\n\x11\x62rick_equip_class\x12\x1f.google.protobuf.MessageOptions\x18\x90N \x01(\x0b\x32\x0b.xbospb.URI:G\n\x11\x62rick_point_class\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x0b\x32\x0b.xbospb.URIb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


BRICK_EQUIP_CLASS_FIELD_NUMBER = 10000
brick_equip_class = _descriptor.FieldDescriptor(
  name='brick_equip_class', full_name='xbospb.brick_equip_class', index=0,
  number=10000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
BRICK_POINT_CLASS_FIELD_NUMBER = 50000
brick_point_class = _descriptor.FieldDescriptor(
  name='brick_point_class', full_name='xbospb.brick_point_class', index=1,
  number=50000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_URI = _descriptor.Descriptor(
  name='URI',
  full_name='xbospb.URI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='xbospb.URI.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xbospb.URI.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=96,
)


_TRIPLE = _descriptor.Descriptor(
  name='Triple',
  full_name='xbospb.Triple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='xbospb.Triple.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicate', full_name='xbospb.Triple.predicate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='xbospb.Triple.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=197,
)

_TRIPLE.fields_by_name['subject'].message_type = _URI
_TRIPLE.fields_by_name['predicate'].message_type = _URI
_TRIPLE.fields_by_name['object'].message_type = _URI
DESCRIPTOR.message_types_by_name['URI'] = _URI
DESCRIPTOR.message_types_by_name['Triple'] = _TRIPLE
DESCRIPTOR.extensions_by_name['brick_equip_class'] = brick_equip_class
DESCRIPTOR.extensions_by_name['brick_point_class'] = brick_point_class
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

URI = _reflection.GeneratedProtocolMessageType('URI', (_message.Message,), dict(
  DESCRIPTOR = _URI,
  __module__ = 'brick_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.URI)
  ))
_sym_db.RegisterMessage(URI)

Triple = _reflection.GeneratedProtocolMessageType('Triple', (_message.Message,), dict(
  DESCRIPTOR = _TRIPLE,
  __module__ = 'brick_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Triple)
  ))
_sym_db.RegisterMessage(Triple)

brick_equip_class.message_type = _URI
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(brick_equip_class)
brick_point_class.message_type = _URI
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(brick_point_class)

# @@protoc_insertion_point(module_scope)
