# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: energize.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nullabletypes_pb2 as nullabletypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='energize.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0e\x65nergize.proto\x12\x06xbospb\x1a\x13nullabletypes.proto\"\x0b\n\tSPBCInput\"*\n\x06Phasor\x12\x11\n\tmagnitude\x18\x01 \x01(\x01\x12\r\n\x05\x61ngle\x18\x02 \x01(\x01\"6\n\x06Target\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x06target\x18\x02 \x01(\x0b\x32\x0e.xbospb.Phasor\"4\n\nSPBCOutput\x12&\n\x0ephasor_targets\x18\x01 \x03(\x0b\x32\x0e.xbospb.Targetb\x06proto3')
  ,
  dependencies=[nullabletypes__pb2.DESCRIPTOR,])




_SPBCINPUT = _descriptor.Descriptor(
  name='SPBCInput',
  full_name='xbospb.SPBCInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=58,
)


_PHASOR = _descriptor.Descriptor(
  name='Phasor',
  full_name='xbospb.Phasor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magnitude', full_name='xbospb.Phasor.magnitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='xbospb.Phasor.angle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=102,
)


_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='xbospb.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xbospb.Target.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='xbospb.Target.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=158,
)


_SPBCOUTPUT = _descriptor.Descriptor(
  name='SPBCOutput',
  full_name='xbospb.SPBCOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phasor_targets', full_name='xbospb.SPBCOutput.phasor_targets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=212,
)

_TARGET.fields_by_name['target'].message_type = _PHASOR
_SPBCOUTPUT.fields_by_name['phasor_targets'].message_type = _TARGET
DESCRIPTOR.message_types_by_name['SPBCInput'] = _SPBCINPUT
DESCRIPTOR.message_types_by_name['Phasor'] = _PHASOR
DESCRIPTOR.message_types_by_name['Target'] = _TARGET
DESCRIPTOR.message_types_by_name['SPBCOutput'] = _SPBCOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SPBCInput = _reflection.GeneratedProtocolMessageType('SPBCInput', (_message.Message,), dict(
  DESCRIPTOR = _SPBCINPUT,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.SPBCInput)
  ))
_sym_db.RegisterMessage(SPBCInput)

Phasor = _reflection.GeneratedProtocolMessageType('Phasor', (_message.Message,), dict(
  DESCRIPTOR = _PHASOR,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Phasor)
  ))
_sym_db.RegisterMessage(Phasor)

Target = _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), dict(
  DESCRIPTOR = _TARGET,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Target)
  ))
_sym_db.RegisterMessage(Target)

SPBCOutput = _reflection.GeneratedProtocolMessageType('SPBCOutput', (_message.Message,), dict(
  DESCRIPTOR = _SPBCOUTPUT,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.SPBCOutput)
  ))
_sym_db.RegisterMessage(SPBCOutput)


# @@protoc_insertion_point(module_scope)
