# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hamilton.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hamilton.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0ehamilton.proto\x12\x06xbospb\"\\\n\x0cHamiltonData\x12\x0e\n\x06serial\x18\x01 \x01(\r\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x04\x12\x1f\n\x03h3c\x18\x04 \x01(\x0b\x32\x12.xbospb.Hamilton3C\"\x95\x02\n\nHamilton3C\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05\x61\x63\x63_x\x18\x03 \x01(\x01\x12\r\n\x05\x61\x63\x63_y\x18\x04 \x01(\x01\x12\r\n\x05\x61\x63\x63_z\x18\x05 \x01(\x01\x12\r\n\x05mag_x\x18\x06 \x01(\x01\x12\r\n\x05mag_y\x18\x07 \x01(\x01\x12\r\n\x05mag_z\x18\x08 \x01(\x01\x12\x0f\n\x07tmp_die\x18\t \x01(\x01\x12\x13\n\x0btmp_voltage\x18\n \x01(\x01\x12\x10\n\x08\x61ir_temp\x18\x0b \x01(\x01\x12\x0f\n\x07\x61ir_hum\x18\x0c \x01(\x01\x12\x0e\n\x06\x61ir_rh\x18\r \x01(\x01\x12\x11\n\tlight_lux\x18\x0e \x01(\x01\x12\x0f\n\x07\x62uttons\x18\x0f \x01(\r\x12\x11\n\toccupancy\x18\x10 \x01(\x01\"\x96\x02\n\x0bHamilton330\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05\x61\x63\x63_x\x18\x03 \x01(\x01\x12\r\n\x05\x61\x63\x63_y\x18\x04 \x01(\x01\x12\r\n\x05\x61\x63\x63_z\x18\x05 \x01(\x01\x12\r\n\x05mag_x\x18\x06 \x01(\x01\x12\r\n\x05mag_y\x18\x07 \x01(\x01\x12\r\n\x05mag_z\x18\x08 \x01(\x01\x12\x0f\n\x07tmp_die\x18\t \x01(\x01\x12\x13\n\x0btmp_voltage\x18\n \x01(\x01\x12\x10\n\x08\x61ir_temp\x18\x0b \x01(\x01\x12\x0f\n\x07\x61ir_hum\x18\x0c \x01(\x01\x12\x0e\n\x06\x61ir_rh\x18\r \x01(\x01\x12\x11\n\tlight_lux\x18\x0e \x01(\x01\x12\x0f\n\x07\x62uttons\x18\x0f \x01(\r\x12\x11\n\toccupancy\x18\x10 \x01(\x01\"\x8c\x02\n\x13HamiltonBRLinkStats\x12\x11\n\tBadFrames\x18\x01 \x01(\x04\x12\x12\n\nLostFrames\x18\x02 \x01(\x04\x12\x18\n\x10\x44ropNotConnected\x18\x03 \x01(\x04\x12\x19\n\x11SumSerialReceived\x18\x04 \x01(\x04\x12\x1a\n\x12SumDomainForwarded\x18\x05 \x01(\x04\x12\x1b\n\x13SumDropNotConnected\x18\x06 \x01(\x04\x12\x19\n\x11SumDomainReceived\x18\x07 \x01(\x04\x12\x1a\n\x12SumSerialForwarded\x18\x08 \x01(\x04\x12\x13\n\x0bPublishOkay\x18\t \x01(\x04\x12\x14\n\x0cPublishError\x18\n \x01(\x04\"\x8e\x01\n\x11HamiltonBRMessage\x12\x0e\n\x06SrcMAC\x18\x01 \x01(\t\x12\r\n\x05SrcIP\x18\x02 \x01(\t\x12\r\n\x05PopID\x18\x03 \x01(\t\x12\x0f\n\x07PopTime\x18\x04 \x01(\x03\x12\x0e\n\x06\x42RTime\x18\x05 \x01(\x03\x12\x0c\n\x04RSSI\x18\x06 \x01(\x05\x12\x0b\n\x03LQI\x18\x07 \x01(\x05\x12\x0f\n\x07Payload\x18\x08 \x01(\x0c\x62\x06proto3')
)




_HAMILTONDATA = _descriptor.Descriptor(
  name='HamiltonData',
  full_name='xbospb.HamiltonData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial', full_name='xbospb.HamiltonData.serial', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='xbospb.HamiltonData.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.HamiltonData.time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h3c', full_name='xbospb.HamiltonData.h3c', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=118,
)


_HAMILTON3C = _descriptor.Descriptor(
  name='Hamilton3C',
  full_name='xbospb.Hamilton3C',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='xbospb.Hamilton3C.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='xbospb.Hamilton3C.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_x', full_name='xbospb.Hamilton3C.acc_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_y', full_name='xbospb.Hamilton3C.acc_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_z', full_name='xbospb.Hamilton3C.acc_z', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_x', full_name='xbospb.Hamilton3C.mag_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_y', full_name='xbospb.Hamilton3C.mag_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_z', full_name='xbospb.Hamilton3C.mag_z', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_die', full_name='xbospb.Hamilton3C.tmp_die', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_voltage', full_name='xbospb.Hamilton3C.tmp_voltage', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_temp', full_name='xbospb.Hamilton3C.air_temp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_hum', full_name='xbospb.Hamilton3C.air_hum', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_rh', full_name='xbospb.Hamilton3C.air_rh', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_lux', full_name='xbospb.Hamilton3C.light_lux', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='xbospb.Hamilton3C.buttons', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='xbospb.Hamilton3C.occupancy', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=398,
)


_HAMILTON330 = _descriptor.Descriptor(
  name='Hamilton330',
  full_name='xbospb.Hamilton330',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='xbospb.Hamilton330.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='xbospb.Hamilton330.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_x', full_name='xbospb.Hamilton330.acc_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_y', full_name='xbospb.Hamilton330.acc_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_z', full_name='xbospb.Hamilton330.acc_z', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_x', full_name='xbospb.Hamilton330.mag_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_y', full_name='xbospb.Hamilton330.mag_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_z', full_name='xbospb.Hamilton330.mag_z', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_die', full_name='xbospb.Hamilton330.tmp_die', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_voltage', full_name='xbospb.Hamilton330.tmp_voltage', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_temp', full_name='xbospb.Hamilton330.air_temp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_hum', full_name='xbospb.Hamilton330.air_hum', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_rh', full_name='xbospb.Hamilton330.air_rh', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_lux', full_name='xbospb.Hamilton330.light_lux', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='xbospb.Hamilton330.buttons', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='xbospb.Hamilton330.occupancy', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=679,
)


_HAMILTONBRLINKSTATS = _descriptor.Descriptor(
  name='HamiltonBRLinkStats',
  full_name='xbospb.HamiltonBRLinkStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='BadFrames', full_name='xbospb.HamiltonBRLinkStats.BadFrames', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LostFrames', full_name='xbospb.HamiltonBRLinkStats.LostFrames', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DropNotConnected', full_name='xbospb.HamiltonBRLinkStats.DropNotConnected', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumSerialReceived', full_name='xbospb.HamiltonBRLinkStats.SumSerialReceived', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDomainForwarded', full_name='xbospb.HamiltonBRLinkStats.SumDomainForwarded', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDropNotConnected', full_name='xbospb.HamiltonBRLinkStats.SumDropNotConnected', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDomainReceived', full_name='xbospb.HamiltonBRLinkStats.SumDomainReceived', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumSerialForwarded', full_name='xbospb.HamiltonBRLinkStats.SumSerialForwarded', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PublishOkay', full_name='xbospb.HamiltonBRLinkStats.PublishOkay', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PublishError', full_name='xbospb.HamiltonBRLinkStats.PublishError', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=950,
)


_HAMILTONBRMESSAGE = _descriptor.Descriptor(
  name='HamiltonBRMessage',
  full_name='xbospb.HamiltonBRMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='SrcMAC', full_name='xbospb.HamiltonBRMessage.SrcMAC', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SrcIP', full_name='xbospb.HamiltonBRMessage.SrcIP', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PopID', full_name='xbospb.HamiltonBRMessage.PopID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PopTime', full_name='xbospb.HamiltonBRMessage.PopTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='BRTime', full_name='xbospb.HamiltonBRMessage.BRTime', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='RSSI', full_name='xbospb.HamiltonBRMessage.RSSI', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LQI', full_name='xbospb.HamiltonBRMessage.LQI', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Payload', full_name='xbospb.HamiltonBRMessage.Payload', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1095,
)

_HAMILTONDATA.fields_by_name['h3c'].message_type = _HAMILTON3C
DESCRIPTOR.message_types_by_name['HamiltonData'] = _HAMILTONDATA
DESCRIPTOR.message_types_by_name['Hamilton3C'] = _HAMILTON3C
DESCRIPTOR.message_types_by_name['Hamilton330'] = _HAMILTON330
DESCRIPTOR.message_types_by_name['HamiltonBRLinkStats'] = _HAMILTONBRLINKSTATS
DESCRIPTOR.message_types_by_name['HamiltonBRMessage'] = _HAMILTONBRMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HamiltonData = _reflection.GeneratedProtocolMessageType('HamiltonData', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONDATA,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonData)
  ))
_sym_db.RegisterMessage(HamiltonData)

Hamilton3C = _reflection.GeneratedProtocolMessageType('Hamilton3C', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTON3C,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Hamilton3C)
  ))
_sym_db.RegisterMessage(Hamilton3C)

Hamilton330 = _reflection.GeneratedProtocolMessageType('Hamilton330', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTON330,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Hamilton330)
  ))
_sym_db.RegisterMessage(Hamilton330)

HamiltonBRLinkStats = _reflection.GeneratedProtocolMessageType('HamiltonBRLinkStats', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONBRLINKSTATS,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonBRLinkStats)
  ))
_sym_db.RegisterMessage(HamiltonBRLinkStats)

HamiltonBRMessage = _reflection.GeneratedProtocolMessageType('HamiltonBRMessage', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONBRMESSAGE,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonBRMessage)
  ))
_sym_db.RegisterMessage(HamiltonBRMessage)


# @@protoc_insertion_point(module_scope)
